==> nextcloud-25.0.4.tgz: nextcloud/apps/weather_status/l10n/ro.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresă necunoscută",
    "No result." : "Niciun rezultat.",
    "Malformed JSON data." : "Informațiile în format JSON au expirat.",
    "Error" : "Eroare",
    "Weather status" : "Starea vremii",
    "Weather status in your dashboard" : "Starea vremii pe ecranul principal",
    "Detect location" : "Detectează locația",
    "Set custom address" : "Setează adresă personalizată",
    "Favorites" : "Favorite",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} cer senin astăzi mai târziu",
    "{temperature} {unit} clear sky" : "{temperature} {unit} cer senin",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} înourat mai târziu",
    "{temperature} {unit} cloudy" : "{temperature} {unit} înourat",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} vreme frumoasă astăzi mai târziu",
    "{temperature} {unit} fair weather" : "{temperature} {unit} vreme frumoasă",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parțial înourat astăzi mai târziu",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parțial înourat",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} încețoșat astăzi mai târziu",
    "{temperature} {unit} foggy" : "{temperature} {unit} încețoșat",
    "More weather for {adr}" : "Mai multe informații despre vreme pentru {adr}",
    "Loading weather" : "Se încarcă datele despre vreme",
    "Remove from favorites" : "Șterge din favorite",
    "Add as favorite" : "Adaugă ca favorit",
    "You are not logged in." : "Nu ești înregistrat",
    "There was an error getting the weather status information." : "A apărut o eroare când sa încercat preluarea de informații despre vreme.",
    "No weather information found" : "Nu s-au găsit informații despre vreme",
    "Location not found" : "Locația nu a fost găsită",
    "There was an error setting the location address." : "A apărut o eroare în timpul setării locației adresei.",
    "There was an error setting the location." : "A apărut o eroare în timpul setării locației.",
    "There was an error saving the mode." : "A apărut o eroare în timpul salvării modului.",
    "There was an error using personal address." : "A apărut o eroare în timpul folosirii adresei perosnale.",
    "Set location for weather" : "Setează locația pentru vreme"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-30.0.5.tgz: nextcloud/apps/weather_status/l10n/ro.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adresă necunoscută",
    "No result." : "Niciun rezultat.",
    "Malformed JSON data." : "Informațiile în format JSON au expirat.",
    "Error" : "Eroare",
    "Weather status" : "Starea vremii",
    "Weather status in your dashboard" : "Starea vremii pe ecranul principal",
    "Detect location" : "Detectează locația",
    "Set custom address" : "Setează adresă personalizată",
    "Favorites" : "Favorite",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} cer senin astăzi mai târziu",
    "{temperature} {unit} clear sky" : "{temperature} {unit} cer senin",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} înourat mai târziu",
    "{temperature} {unit} cloudy" : "{temperature} {unit} înourat",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} vreme frumoasă astăzi mai târziu",
    "{temperature} {unit} fair weather" : "{temperature} {unit} vreme frumoasă",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parțial înourat astăzi mai târziu",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parțial înourat",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} încețoșat astăzi mai târziu",
    "{temperature} {unit} foggy" : "{temperature} {unit} încețoșat",
    "More weather for {adr}" : "Mai multe informații despre vreme pentru {adr}",
    "Loading weather" : "Se încarcă datele despre vreme",
    "Set location for weather" : "Setează locația pentru vreme",
    "Remove from favorites" : "Șterge din favorite",
    "Add as favorite" : "Adaugă ca favorit",
    "You are not logged in." : "Nu ești înregistrat",
    "There was an error getting the weather status information." : "A apărut o eroare când sa încercat preluarea de informații despre vreme.",
    "No weather information found" : "Nu s-au găsit informații despre vreme",
    "Location not found" : "Locația nu a fost găsită",
    "There was an error setting the location address." : "A apărut o eroare în timpul setării locației adresei.",
    "There was an error setting the location." : "A apărut o eroare în timpul setării locației.",
    "There was an error saving the mode." : "A apărut o eroare în timpul salvării modului.",
    "There was an error using personal address." : "A apărut o eroare în timpul folosirii adresei perosnale."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
